@@ -1,18 +1,19 @@
-# Authors: Clemens Brunner <clemens.brunner@gmail.com>
+# © MNELAB developers
 #
 # License: BSD (3-clause)
 
-import sys
 import multiprocessing as mp
+import sys
+
 import matplotlib
-from qtpy.QtWidgets import QApplication
-from qtpy.QtCore import Qt
+from PySide6.QtCore import Qt
+from PySide6.QtGui import QIcon
+from PySide6.QtWidgets import QApplication
 
 from .mainwindow import MainWindow
 from .model import Model
 
-
-__version__ = "0.6.6"
+__version__ = "0.8.0"
 
 
 def main():
@@ -20,22 +21,26 @@ def main():
     app_name = "MNELAB"
     if sys.platform.startswith("darwin"):
         # set bundle name on macOS (app name shown in the menu bar)
+        # this must be done before the app is created
         from Foundation import NSBundle
         bundle = NSBundle.mainBundle()
         info = bundle.localizedInfoDictionary() or bundle.infoDictionary()
         info["CFBundleName"] = app_name
 
-    matplotlib.use("Qt5Agg")
+    matplotlib.use("QtAgg")
     app = QApplication(sys.argv)
     app.setApplicationName(app_name)
     app.setOrganizationName("cbrnr")
     if sys.platform.startswith("darwin"):
-        app.setAttribute(Qt.AA_DontShowIconsInMenus, True)
-    app.setAttribute(Qt.AA_UseHighDpiPixmaps)
+        app.setAttribute(Qt.ApplicationAttribute.AA_DontShowIconsInMenus, True)
+        app.setWindowIcon(QIcon("mnelab/icons/mnelab-logo-macos.svg"))
+    else:
+        app.setWindowIcon(QIcon("mnelab/icons/mnelab-logo.svg"))
+    app.setAttribute(Qt.ApplicationAttribute.AA_UseHighDpiPixmaps)
     model = Model()
     model.view = MainWindow(model)
     if len(sys.argv) > 1:  # open files from command line arguments
         for f in sys.argv[1:]:
             model.load(f)
     model.view.show()
-    sys.exit(app.exec_())
+    sys.exit(app.exec())
